@@ -17,9 +17,6 @@ class Movement:
 		pass
 
 	def add_block(self, block):
-		block.key = self.default_key
-		block.bpm = self.default_bpm
-		block.wildness = self.default_wildness
 		self.blocks.append(block)
 
 	def add_progression(self, progression):
