@@ -7,6 +7,9 @@ class Drum(Instrument):
 		params["channel"] = 9
 		Instrument.__init__(self, params)
 
+	def acoustic_bass(self):
+		return [Note("B", 2)]
+
 	def bass(self):
 		return [Note("C", 2)]
 
@@ -28,6 +31,12 @@ class Drum(Instrument):
 	def snare(self):
 		return [Note("E", 2)]
 
+	def electric_snare(self):
+		return snare
+
+	def acoustic_snare(Self):
+		return [Note("D", 2)]
+
 	def lowest_tom(self):
 		return Note("F", 2)
 
@@ -45,3 +54,18 @@ class Drum(Instrument):
 
 	def highest_tom(self):
 		return Note("D", 3)
+
+	def high_bongo(self):
+		return Note("C", 4)
+
+	def low_bongo(self):
+		return Note("C#", 4)
+
+	def mute_high_conga(self):
+		return Note("D", 4)
+
+	def open_high_conga(self):
+		return Note("D#", 4)
+
+	def low_conga(self):
+		return Note("E", 4)
