@@ -5,5 +5,7 @@ from Metronome import Metronome
 from Snare import Snare
 from DanceBeat import DanceBeat
 from Toms import Toms
+from Bongo import Bongo
+from Conga import Conga
 
-__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome', 'Snare', 'DanceBeat', 'Toms']
+__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome', 'Snare', 'DanceBeat', 'Toms', 'Bongo', 'Conga']
