@@ -2,14 +2,18 @@ from Instrument import Instrument
 from mingus.core import chords
 from mingus.containers.Note import Note
 from mingus.containers.NoteContainer import NoteContainer
-from random import random
+from random import random, randrange
 
 
 class FastStridePianist(Instrument):
 
 	def __init__(self, params):
-		params["let_ring"] = True
-		params["channel"] = 1
+		if 'let_ring' not in params:
+			params["let_ring"] = True
+		if 'channel' not in params:
+			params["channel"] = 1
+		if 'midi_instr' not in params:
+			params["midi_instr"] = randrange(1, 9)
 		Instrument.__init__(self, params)
 
 	def generate_note(self, state):
