@@ -6,6 +6,7 @@ from qtGUI.aboutDialog import Ui_aboutDialog
 from qtGUI.instrumentDialog import Ui_instrumentDialog
 from qtGUI.progressionDialog import Ui_progressionDialog
 from qtGUI.blockDialog import Ui_blockDialog
+from qtGUI.preferencesDialog import Ui_preferencesDialog
 from mingus.containers.Instrument import MidiInstrument
 from mingus.core import chords
 from mingus.core import progressions as mingus_progressions
@@ -143,6 +144,63 @@ def combo_index_by_text(combo, text):
 	return -1
 
 
+class PreferencesDialog(QtGui.QDialog):
+
+	def __init__(self):
+		QtGui.QDialog.__init__(self)
+		self.ui = Ui_preferencesDialog()
+		self.ui.setupUi(self)
+		self.setup()
+
+	def setup(self):
+		for x in ['default', 'alsa', 'oss', 'jack', 'portaudio', 'coreaudio', 
+				'sndmgr', 'Direct Sound']:
+			self.ui.driver.addItem(x)
+
+		self.connect(self.ui.buttonBox,
+			QtCore.SIGNAL("accepted()"),
+			self.open_window)
+
+		self.connect(self.ui.browsebutton,
+			QtCore.SIGNAL("clicked()"),
+			self.load_dialog)
+
+		self.connect(self.ui.no_fluidsynth,
+			QtCore.SIGNAL("stateChanged(int)"),
+			lambda x: self.ui.browsebutton.setEnabled(not(x)) or \
+					self.ui.driver.setEnabled(not(x)))
+
+	def toggle_enabled(self):
+		print "asdsdad"
+		if self.ui.no_fluidsynth.isChecked():
+			self.ui.browsebutton.enabled()
+		else:
+			self.ui.browsebutton.enabled()
+
+
+
+	def open_window(self):
+		soundfont = str(self.ui.soundfont.text())
+		driver = str(self.ui.driver.currentText())
+		no_fluidsynth = int(self.ui.no_fluidsynth.isChecked())
+
+		if no_fluidsynth:
+			show_main()
+			self.reject()
+		else:
+			if soundfont != "":
+				show_main(False, soundfont, driver)
+				self.reject()
+
+	def load_dialog(self):
+		f = QtGui.QFileDialog()
+		s = f.getOpenFileName(self, "Load soundfont.",
+				"/home", "Soundfont (*.sf2)")
+		if s != "":
+			self.ui.soundfont.setText(s)
+
+
+
 class ProgressionDialog(QtGui.QDialog):
 
 	def __init__(self, item):
@@ -494,8 +552,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 	def fill_combos(self):
 		for x in Options.get_available_instruments():
 			self.ui.instrumentcombo.addItem(x)
-		for x in Options.get_available_blocks():
-			self.ui.blockcombo.addItem(x)
 		for x in Options.get_available_progressions():
 			prog = Options.progression_to_string(getattr(Progressions, x))
 			self.ui.progressioncombo.addItem("%s %s" % (x, prog))
@@ -505,9 +561,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.ui.resolution.addItem(str(x))
 		for x in diatonic.basic_keys:
 			self.ui.key.addItem(x)
-		for x in ['default', 'alsa', 'oss', 'jack', 'portaudio', 'coreaudio', 
-				'sndmgr', 'Direct Sound']:
-			self.ui.driver.addItem(x)
 		for x in ['', 'cli', 'lines', 'blocks', 'mixed']:
 			self.ui.visualization.addItem(x)
 				
@@ -588,7 +641,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.actionNew,
 			QtCore.SIGNAL("activated()"),
 			self.set_defaults)
-		
 	
 
 	def set_defaults(self):
@@ -620,7 +672,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.set_title()
 	
 	def add_block(self):
-		self.ui.blocks.addItem(self.ui.blockcombo.currentText())
+		self.ui.blocks.addItem("Block")
 		self.ui.blocks.setCurrentRow(int(self.ui.blocks.count()) - 1)
 		self.edit_block()
 
@@ -639,8 +691,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.ui.progressions.takeItem(i)
 
 	def add_instrument(self):
-		self.ui.instruments.addItem(
-			self.ui.instrumentcombo.currentText())
+		self.ui.instruments.addItem(self.ui.instrumentcombo.currentText())
+		self.ui.instruments.setCurrentRow(int(self.ui.instruments.count()) -1)
+		self.edit_instrument()
 
 	def remove_instrument(self):
 		i = self.ui.instruments.currentRow()
@@ -759,8 +812,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		o = options
 
 		# LineEdit
-		self.ui.soundfont.setText(o.SF2)
-		self.ui.projectname.setText(o.project)
+		self.ui.projectname.setText(o.project.replace("_", " "))
 		if hasattr(o, "author"):
 			self.ui.author.setText(o.author)
 		else:
@@ -789,7 +841,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 		# CheckBoxes
 		self.ui.swing.setChecked(bool(o.swing))
-		self.ui.no_fluidsynth.setChecked(bool(o.no_fluidsynth))
 
 		# Lists
 		self.ui.blocks.clear()
@@ -824,7 +875,8 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		# ComboBoxes
 		o.resolution = int(str(self.ui.resolution.currentText()))
 		o.key = str(self.ui.key.currentText())
-		o.driver = str(self.ui.driver.currentText())
+		o.driver = self.driver
+		o.SF2 = self.soundfont
 		o.frontend = str(self.ui.visualization.currentText())
 		if o.frontend == '':
 			o.frontend = None
@@ -839,14 +891,13 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 		# Checkboxes
 		o.swing = int(self.ui.swing.isChecked())
-		o.no_fluidsynth = int(self.ui.no_fluidsynth.isChecked())
+		o.no_fluidsynth = self.no_fluidsynth
 
 		o.instrument = self.get_instruments()
 		o.progression = self.get_progressions()
 		o.blocks = self.get_blocks()
 
 		# LineEdit
-		o.SF2 = str(self.ui.soundfont.text())
 		project = str(self.ui.projectname.text()).replace(" ", "_")
 		if project == "":
 			project = "Untitled"
@@ -924,7 +975,21 @@ class SequencerThread(QtCore.QThread):
 		self.seq.play()
 
 
+def show_main(no_sound = True, soundfont = '', driver=''):
+	i = ImproviserMainWindow()
+	if no_sound:
+		i.no_fluidsynth = True
+		i.soundfont = ''
+		i.driver = ''
+	else:
+		i.no_fluidsynth = False
+		i.soundfont = soundfont
+		i.driver = driver
+	i.show()
+
 app = QtGui.QApplication(argv)
-i = ImproviserMainWindow()
-i.show()
+p = PreferencesDialog()
+p.show()
 app.exec_()
+
+
